==> lightdash_client_python-0.1286.0-py3-none-any.whl: lightdash_client/models/api_validation_dismiss_response.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.api_validation_dismiss_response_status import (
    ApiValidationDismissResponseStatus,
)

T = TypeVar("T", bound="ApiValidationDismissResponse")


@_attrs_define
class ApiValidationDismissResponse:
    """
    Attributes:
        status (ApiValidationDismissResponseStatus):
    """

    status: ApiValidationDismissResponseStatus
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        status = self.status.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "status": status,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        status = ApiValidationDismissResponseStatus(d.pop("status"))

        api_validation_dismiss_response = cls(
            status=status,
        )

        api_validation_dismiss_response.additional_properties = d
        return api_validation_dismiss_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> lightdash_client_python-0.1403.1-py3-none-any.whl: lightdash_client/models/api_validation_dismiss_response.py <==
from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.api_validation_dismiss_response_status import ApiValidationDismissResponseStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiValidationDismissResponse")


@_attrs_define
class ApiValidationDismissResponse:
    """
    Attributes:
        status (ApiValidationDismissResponseStatus):
    """

    status: ApiValidationDismissResponseStatus
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        status = self.status.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "status": status,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        status = ApiValidationDismissResponseStatus(d.pop("status"))

        api_validation_dismiss_response = cls(
            status=status,
        )

        api_validation_dismiss_response.additional_properties = d
        return api_validation_dismiss_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
